From 7378f854c3b3afa5b2f1f9efb40d38e6528881a0 Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Sat, 13 May 2017 00:23:17 +0200
Subject: [PATCH 01/10] Publish valid semver task independently of the branch

---
 tasks/publish.js | 18 +++++++++++++-----
 1 file changed, 13 insertions(+), 5 deletions(-)

diff --git a/tasks/publish.js b/tasks/publish.js
index 55ea20a71..38039c6d4 100644
--- a/tasks/publish.js
+++ b/tasks/publish.js
@@ -15,14 +15,22 @@ module.exports = function(grunt) {
       git.commitInfo(function(err, info) {
         grunt.log.writeln('tag: ' + info.tagName);
 
+        var files = [];
+
+        // Publish the master as "latest" and with the commit-id
         if (info.isMaster) {
-          initSDK();
+          files.push('-latest');
+          files.push('-' + info.head);
+        }
 
-          var files = ['-latest', '-' + info.head];
-          if (info.tagName && semver.valid(info.tagName)) {
-            files.push('-' + info.tagName);
-          }
+        // Publish tags by their tag-name
+        if (info.tagName && semver.valid(info.tagName)) {
+          files.push('-' + info.tagName);
+        }
 
+        if (files.length > 0) {
+          initSDK();
+          grunt.log.writeln('publishing files: ' + JSON.stringify(files));
           publish(fileMap(files), done);
         } else {
           // Silently ignore for branches

From 6e6269fcd7de568a492d8a0a3277dbc136190336 Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Sat, 13 May 2017 13:00:56 +0200
Subject: [PATCH 02/10] Use istanbul/lib/cli.js instead of
 node_modules/.bin/istanbul

Fixes #1331

Due to the way, "bin"-files are distributed into the node_modules/.bin
directory on Windows, the task "test:cov" did not work on Windows.
This commit uses the node-script directly.
---
 tasks/test.js | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tasks/test.js b/tasks/test.js
index 18a6c26ba..d7ce04d0a 100644
--- a/tasks/test.js
+++ b/tasks/test.js
@@ -32,7 +32,7 @@ module.exports = function(grunt) {
   grunt.registerTask('test:cov', function() {
     var done = this.async();
 
-    var runner = childProcess.fork('node_modules/.bin/istanbul', ['cover', '--source-map', '--', './spec/env/runner.js'], {stdio: 'inherit'});
+    var runner = childProcess.fork('node_modules/istanbul/lib/cli.js', ['cover', '--source-map', '--', './spec/env/runner.js'], {stdio: 'inherit'});
     runner.on('close', function(code) {
       if (code != 0) {
         grunt.fatal(code + ' tests failed');
@@ -55,7 +55,7 @@ module.exports = function(grunt) {
   grunt.registerTask('test:check-cov', function() {
     var done = this.async();
 
-    var runner = childProcess.fork('node_modules/.bin/istanbul', ['check-coverage', '--statements', '100', '--functions', '100', '--branches', '100', '--lines 100'], {stdio: 'inherit'});
+    var runner = childProcess.fork('node_modules/istanbul/lib/cli.js', ['check-coverage', '--statements', '100', '--functions', '100', '--branches', '100', '--lines 100'], {stdio: 'inherit'});
     runner.on('close', function(code) {
       if (code != 0) {
         grunt.fatal('Coverage check failed: ' + code);

From b50ef038238be231b931810b2944c9ef25622467 Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Sat, 13 May 2017 22:56:30 +0200
Subject: [PATCH 03/10] Force LF line-endings for spec/artifacts

Fixes #1331
---
 .gitattributes | 1 +
 1 file changed, 1 insertion(+)
 create mode 100644 .gitattributes

diff --git a/.gitattributes b/.gitattributes
new file mode 100644
index 000000000..cb9d99bb5
--- /dev/null
+++ b/.gitattributes
@@ -0,0 +1 @@
+*.handlebars text eol=lf

From bdfdbea09c15dafe581081ff8b7ef8040b1208be Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Sun, 14 May 2017 22:49:19 +0200
Subject: [PATCH 04/10] Ensure LF line-edings in lexer-files (*.l)

Related to #1233
---
 .gitattributes | 4 ++++
 1 file changed, 4 insertions(+)

diff --git a/.gitattributes b/.gitattributes
index cb9d99bb5..5e1a5da03 100644
--- a/.gitattributes
+++ b/.gitattributes
@@ -1 +1,5 @@
+# Handlebars templates in test cases
 *.handlebars text eol=lf
+
+# Lexer files
+*.l text eol=lf

From 2e21e2bc9a19c2be258c98a0c5c97e0f74228315 Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Sun, 14 May 2017 23:10:14 +0200
Subject: [PATCH 05/10] Run integration test with `node handlebars -a ...` on
 Windows

Fixes #1233

NodeJS files cannot be executed directly on Windows.
---
 tasks/test.js | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/tasks/test.js b/tasks/test.js
index d7ce04d0a..e7825d015 100644
--- a/tasks/test.js
+++ b/tasks/test.js
@@ -1,11 +1,14 @@
 var childProcess = require('child_process'),
-    fs = require('fs');
+    fs = require('fs'),
+    os = require('os');
 
 module.exports = function(grunt) {
   grunt.registerTask('test:bin', function() {
     var done = this.async();
 
-    childProcess.exec('./bin/handlebars -a spec/artifacts/empty.handlebars', function(err, stdout) {
+    // On Windows, the executable handlebars.js file cannot be run directly
+    var prefix = os.type().match(/^Windows/) ? process.argv[0] : '';
+    childProcess.exec(prefix + ' ./bin/handlebars -a spec/artifacts/empty.handlebars', function(err, stdout) {
       if (err) {
         throw err;
       }

From ed879a6068d8c2ed27ab1f95154f1489eae46e59 Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Sun, 14 May 2017 23:56:23 +0200
Subject: [PATCH 06/10] Ensure LF line-edings in handlebars-template fixtures
 (*.hbs)

Fixes #1331
---
 .gitattributes | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/.gitattributes b/.gitattributes
index 5e1a5da03..eeda54e24 100644
--- a/.gitattributes
+++ b/.gitattributes
@@ -1,5 +1,6 @@
-# Handlebars templates in test cases
+# Handlebars-template fixtures in test cases need deterministic eol
 *.handlebars text eol=lf
+*.hbs text eol=lf
 
-# Lexer files
+# Lexer files as well
 *.l text eol=lf

From cc554a581337cd6b5ffdc90a36e79d8fe1c7a7d7 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Luiz=20Am=C3=A9rico?= <luizamericop@gmail.com>
Date: Sun, 21 Aug 2016 22:50:20 +0200
Subject: [PATCH 07/10] Fix build in windows

(cherry picked from commit 275ab37)
---
 tasks/test.js | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/tasks/test.js b/tasks/test.js
index e7825d015..342a28362 100644
--- a/tasks/test.js
+++ b/tasks/test.js
@@ -13,8 +13,9 @@ module.exports = function(grunt) {
         throw err;
       }
 
-      var expected = fs.readFileSync('./spec/expected/empty.amd.js');
-      if (stdout.toString() !== expected.toString()) {
+      var expected = fs.readFileSync('./spec/expected/empty.amd.js').toString().replace(/\r\n/g, '\n');
+
+      if (stdout.toString() !== expected) {
         throw new Error('Expected binary output differed:\n\n"' + stdout + '"\n\n"' + expected + '"');
       }
 

From 8a836e22727edbf07d63b8af6905d64b37b16d85 Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Thu, 18 May 2017 21:18:34 +0200
Subject: [PATCH 08/10] Handlebars.compile() does not modify "options" anymore

Fixes #1327

- This commit creates a shallow copy of the "options" passed to
  Handlebars.compile() in order to prevent modifications
- Note that "new Handlebars.Compiler().compile(..., options)" still
  modify the options object. This might change in the future, if
  anybody needs a fix for that.
---
 lib/handlebars/compiler/compiler.js |  3 ++-
 spec/compiler.js                    | 12 ++++++++++++
 2 files changed, 14 insertions(+), 1 deletion(-)

diff --git a/lib/handlebars/compiler/compiler.js b/lib/handlebars/compiler/compiler.js
index 987d0d459..c4bfe44ed 100644
--- a/lib/handlebars/compiler/compiler.js
+++ b/lib/handlebars/compiler/compiler.js
@@ -70,7 +70,7 @@ Compiler.prototype = {
       for (let name in knownHelpers) {
         /* istanbul ignore else */
         if (name in knownHelpers) {
-          options.knownHelpers[name] = knownHelpers[name];
+          this.options.knownHelpers[name] = knownHelpers[name];
         }
       }
     }
@@ -488,6 +488,7 @@ export function compile(input, options = {}, env) {
     throw new Exception('You must pass a string or Handlebars AST to Handlebars.compile. You passed ' + input);
   }
 
+  options = Object.assign({}, options);
   if (!('data' in options)) {
     options.data = true;
   }
diff --git a/spec/compiler.js b/spec/compiler.js
index 95941bcc3..02dad6751 100644
--- a/spec/compiler.js
+++ b/spec/compiler.js
@@ -73,6 +73,18 @@ describe('compiler', function() {
     it('can pass through an empty string', function() {
       equal(Handlebars.compile('')(), '');
     });
+
+    it('should not modify the options.data property(GH-1327)', function() {
+      var options = {data: [{a: 'foo'}, {a: 'bar'}]};
+      Handlebars.compile('{{#each data}}{{@index}}:{{a}} {{/each}}', options)();
+      equal(JSON.stringify(options, 0, 2), JSON.stringify({data: [{a: 'foo'}, {a: 'bar'}]}, 0, 2));
+    });
+
+    it('should not modify the options.knownHelpers property(GH-1327)', function() {
+      var options = {knownHelpers: {}};
+      Handlebars.compile('{{#each data}}{{@index}}:{{a}} {{/each}}', options)();
+      equal(JSON.stringify(options, 0, 2), JSON.stringify({knownHelpers: {}}, 0, 2));
+    });
   });
 
   describe('#precompile', function() {

From 5333f316c321d979e4eb7a72dbaad076e09e26ff Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Sun, 21 May 2017 13:38:28 +0200
Subject: [PATCH 09/10] Update release notes

---
 release-notes.md | 19 ++++++++++++++++++-
 1 file changed, 18 insertions(+), 1 deletion(-)

diff --git a/release-notes.md b/release-notes.md
index 36bec7890..900217b9f 100644
--- a/release-notes.md
+++ b/release-notes.md
@@ -2,7 +2,24 @@
 
 ## Development
 
-[Commits](https://github.com/nknapp/handlebars.js/compare/v4.0.8...master)
+[Commits](https://github.com/nknapp/handlebars.js/compare/v4.0.9...master)
+
+## v4.0.9 - May 21st, 2017
+
+- [#1327](https://github.com/wycats/handlebars.js/issues/1327) Handlebars.compile() does not modify "options" anymore
+- pending [#1331](https://github.com/wycats/handlebars.js/issues/1331) Attempts to build Handlebars in a Windows environment
+  - Fix build in windows - cc554a5
+  - Ensure LF line-edings in handlebars-template fixtures (*.hbs) - ed879a6
+  - Run integration test with `node handlebars -a ...` on Windows - 2e21e2b
+  - Ensure LF line-edings in lexer-files (*.l) - bdfdbea
+  - Force LF line-endings for spec/artifacts - b50ef03
+  - Use istanbul/lib/cli.js instead of node_modules/.bin/istanbul - 6e6269f
+- TravisCI: Publish valid semver tags independently of the branch - 7378f85
+
+Compatibility notes:
+- No compatibility issues are expected.
+
+[Commits](https://github.com/nknapp/handlebars.js/compare/v4.0.8...v4.0.9)
 
 ## v4.0.8 - May 2nd, 2017
 - [#1341](https://github.com/wycats/handlebars.js/issues/1341) [#1342](https://github.com/wycats/handlebars.js/issues/1342) Allow partial-blocks to be executed without "options" ([@nknapp](https://github.com/nknapp)) - a00c598

From 5ec78a8c70ac674f39a8408e04d59bd40340f6fe Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Sun, 21 May 2017 13:39:05 +0200
Subject: [PATCH 10/10] v4.0.9

---
 components/bower.json           | 2 +-
 components/handlebars.js.nuspec | 2 +-
 lib/handlebars/base.js          | 2 +-
 package.json                    | 2 +-
 4 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/components/bower.json b/components/bower.json
index 55eca01a7..839530885 100644
--- a/components/bower.json
+++ b/components/bower.json
@@ -1,6 +1,6 @@
 {
   "name": "handlebars",
-  "version": "4.0.8",
+  "version": "4.0.9",
   "main": "handlebars.js",
   "license": "MIT",
   "dependencies": {}
diff --git a/components/handlebars.js.nuspec b/components/handlebars.js.nuspec
index 8de339819..e82a7891b 100644
--- a/components/handlebars.js.nuspec
+++ b/components/handlebars.js.nuspec
@@ -2,7 +2,7 @@
 <package>
 	<metadata>
 		<id>handlebars.js</id>
-		<version>4.0.8</version>
+		<version>4.0.9</version>
 		<authors>handlebars.js Authors</authors>
 		<licenseUrl>https://github.com/wycats/handlebars.js/blob/master/LICENSE</licenseUrl>
 		<projectUrl>https://github.com/wycats/handlebars.js/</projectUrl>
diff --git a/lib/handlebars/base.js b/lib/handlebars/base.js
index a684797c9..2968a4dfc 100644
--- a/lib/handlebars/base.js
+++ b/lib/handlebars/base.js
@@ -4,7 +4,7 @@ import {registerDefaultHelpers} from './helpers';
 import {registerDefaultDecorators} from './decorators';
 import logger from './logger';
 
-export const VERSION = '4.0.8';
+export const VERSION = '4.0.9';
 export const COMPILER_REVISION = 7;
 
 export const REVISION_CHANGES = {
diff --git a/package.json b/package.json
index 095917552..ef3ff157a 100644
--- a/package.json
+++ b/package.json
@@ -1,7 +1,7 @@
 {
   "name": "handlebars",
   "barename": "handlebars",
-  "version": "4.0.8",
+  "version": "4.0.9",
   "description": "Handlebars provides the power necessary to let you build semantic templates effectively with no frustration",
   "homepage": "http://www.handlebarsjs.com/",
   "keywords": [
